# PayerMax
PayerMax SDK

## Installation
```sh
npm install payermax --save
# or
yarn add payermax
```

## Documentation
See the PayerMax API for [documentation](https://docs.payermax.com/).

## Usage
Note: After integrating the SDK, all API interfaces do not need to pass parameter  `sign、merchantId`

```js
const PayerMax = require('payermax');

const payerMax = new PayerMax({
  // Secret key (Required)
  secretKey: 'Merchant security key',

  // Merchant ID (Required)
  merchantId: 'Merchant ID assigned by PayerMax',

  // Debugging environment: Test or Prod (Optional)
  // default: Prod
  env: 'Test',

  // https configuration (Optional)
  // For details, please refer to the NodeJS https chapter
  https: {
    timeout: 1000
  }
});
```

### Payment Service General API
For detailed parameter description, please refer to the document [Payment Service](https://docs.payermax.com/#/12?page_id=84)
```js
// Example: create a payment order
payerMax.payment.post({
  bizType: 'CUSTOMIZE',
  orderId: 'order1234456',
  userId: 'user123456',
  subject: 'shop title',
  countryCode: 'ID',
  currency: 'IDR',
  totalAmount: '1000',
  frontCallBackUrl: 'https://www.payermax.com',
  version: '2.3',
  ...params
  // merchantId (Optional)
  // sign (Optional)
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

### Disbursement Service General API
For detailed parameter description, please refer to the document [Disbursement Service](https://docs.payermax.com/#/12?page_id=97)
```js
payerMax.disbursement.post({
  bizType: 'singlePayment',
  version: '2.0'
  ...params
  // merchantId (Optional)
  // sign (Optional)
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

## Specify API

#### Create a payment order
For detailed parameter description, please refer to the document [API](https://docs.payermax.com/#/12?page_id=91)
```js
payerMax.payment.create({
  bizType: 'According to the authority of the contracted collection service',
  ...params
  // merchantId (Optional)
  // sign (Optional)
  // version (Optional)
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

#### Payment Result Query
For detailed parameter description, please refer to the document [API](https://docs.payermax.com/#/12?page_id=93)
```js
payerMax.payment.queryReceiptResult({
  orderId: 'Merchant order id'
  // bizType (Optional)
  // merchantId (Optional)
  // sign (Optional)
  // version (Optional)
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

#### Refund
For detailed parameter description, please refer to the document [API](https://docs.payermax.com/#/12?page_id=131)
```js
payerMax.payment.refund({
  refundId: 'Refund request id',
  orderId: 'Original merchant order id',
  amount: 'Refund amount',
  currency: 'Currency code',
  callbackUrl: 'Refund result callback URL', // (Optional)
  comment: 'Refund comments', // (Optional)
  email: 'Email', // (Optional)
  // bizType (Optional)
  // merchantId (Optional)
  // sign (Optional)
  // version (Optional)
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

#### Refund Result Query
For detailed parameter description, please refer to the document [API](https://docs.payermax.com/#/12?page_id=93)
```js
payerMax.payment.queryRefundResult({
  refundId: 'Refund request id'
  // bizType (Optional)
  // merchantId (Optional)
  // sign (Optional)
  // version (Optional)
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

#### Create a disbursement order
For detailed parameter description, please refer to the document [API](https://docs.payermax.com/#/12?page_id=98)
```js
payerMax.disbursement.create({
  orderId: 'Merchant order ID',
  ...params
  // bizType (Optional)
  // merchantId (Optional)
  // sign (Optional)
  // version (Optional)
})
.then(res => console.log(res))
.catch(err => console.log(err));
```

### Disbursement Result Query
For detailed parameter description, please refer to the document [API](https://docs.payermax.com/#/12?page_id=100)
```js
payerMax.disbursement.queryResult({
  orderId: 'Merchant order ID',
  // bizType (Optional)
  // merchantId (Optional)
  // sign (Optional)
  // version (Optional)
})
.then(res => console.log(res))
.catch(err => console.log(err));
```